@@ -12,24 +12,26 @@
 #include <wx/intl.h>
 #include <wx/log.h>
 
+#include "config/GOConfigFileReader.h"
+#include "config/GOConfigReader.h"
+#include "config/GOConfigReaderDB.h"
+
 #include "GOArchive.h"
 #include "GOArchiveFile.h"
 #include "GOFile.h"
 #include "GOOrgan.h"
 #include "GOOrganList.h"
 #include "GOPath.h"
-#include "config/GOConfigFileReader.h"
-#include "config/GOConfigReader.h"
-#include "config/GOConfigReaderDB.h"
 
 GOArchiveManager::GOArchiveManager(
-  GOOrganList &OrganList, const GOSettingDirectory &CacheDir)
-  : m_OrganList(OrganList), m_CacheDir(CacheDir) {}
+  GOOrganList &OrganList, const wxString &cacheDir)
+  : m_OrganList(OrganList), m_CacheDir(cacheDir) {}
 
 GOArchiveManager::~GOArchiveManager() {}
 
 GOArchive *GOArchiveManager::OpenArchive(const wxString &path) {
   GOArchive *archive = new GOArchive(m_CacheDir);
+
   if (!archive->OpenArchive(path)) {
     delete archive;
     return NULL;
@@ -84,8 +86,13 @@ bool GOArchiveManager::ReadIndex(GOArchive *archive, bool InstallOrgans) {
       wxString RecordingDetails
         = cfg.ReadString(CMBSetting, group, wxT("RecordingDetails"), false);
       if (InstallOrgans)
-        organs.push_back(
-          GOOrgan(odf, id, ChurchName, OrganBuilder, RecordingDetails));
+        organs.push_back(GOOrgan(
+          odf,
+          id,
+          archive->GetPath(),
+          ChurchName,
+          OrganBuilder,
+          RecordingDetails));
     }
 
     GOArchiveFile a(
