@@ -15,6 +15,7 @@
 #include <wx/image.h>
 #include <wx/menu.h>
 #include <wx/msgdlg.h>
+#include <wx/platinfo.h>
 #include <wx/sizer.h>
 #include <wx/spinctrl.h>
 #include <wx/splash.h>
@@ -23,12 +24,14 @@
 #include <algorithm>
 
 #include "archive/GOArchiveManager.h"
+#include "combinations/GOSetter.h"
 #include "config/GOConfig.h"
 #include "dialogs/GOProgressDialog.h"
 #include "dialogs/GOSelectOrganDialog.h"
 #include "dialogs/GOSplash.h"
 #include "dialogs/settings/GOSettingsDialog.h"
 #include "dialogs/settings/GOSettingsReason.h"
+#include "files/GOStdFileName.h"
 #include "gui/GOGUIPanel.h"
 #include "help/GOHelpRequestor.h"
 #include "midi/GOMidi.h"
@@ -40,14 +43,13 @@
 #include "GOApp.h"
 #include "GOAudioGauge.h"
 #include "GOCacheCleaner.h"
-#include "GODefinitionFile.h"
 #include "GODocument.h"
 #include "GOEvent.h"
 #include "GOLogicalRect.h"
 #include "GOOrgan.h"
+#include "GOOrganController.h"
 #include "GOPath.h"
 #include "GOProperties.h"
-#include "GOSetter.h"
 #include "Images.h"
 #include "go_ids.h"
 #include "go_limits.h"
@@ -162,9 +164,6 @@ GOFrame::GOFrame(
 
   m_recent_menu = new wxMenu;
 
-  wxToolBar *tb = CreateToolBar(wxNO_BORDER | wxTB_HORIZONTAL | wxTB_FLAT);
-  tb->SetToolBitmapSize(wxSize(16, 16));
-
   wxMenu *preset_menu = new wxMenu;
   for (unsigned i = ID_PRESET_0; i <= ID_PRESET_LAST; i++)
     preset_menu->Append(
@@ -249,21 +248,31 @@ GOFrame::GOFrame(
   wxMenu *help_menu = new wxMenu;
   help_menu->Append(wxID_HELP, _("&Help\tF1"), wxEmptyString, wxITEM_NORMAL);
   help_menu->Append(wxID_ABOUT, _("&About"), wxEmptyString, wxITEM_NORMAL);
+  m_panel_menu = new wxMenu();
 
-  tb->AddTool(
+  wxMenuBar *menu_bar = new wxMenuBar;
+  menu_bar->Append(m_file_menu, _("&File"));
+  menu_bar->Append(m_audio_menu, _("&Audio/Midi"));
+  menu_bar->Append(m_panel_menu, _("&Panel"));
+  menu_bar->Append(help_menu, _("&Help"));
+  SetMenuBar(menu_bar);
+
+  m_ToolBar = CreateToolBar(wxNO_BORDER | wxTB_HORIZONTAL | wxTB_FLAT);
+  m_ToolBar->SetToolBitmapSize(wxSize(16, 16));
+  m_ToolBar->AddTool(
     ID_AUDIO_MEMSET,
     _("&Memory Set\tShift"),
     GetImage_set(),
     _("Memory Set"),
     wxITEM_CHECK);
-  tb->AddTool(
+  m_ToolBar->AddTool(
     ID_MEMORY,
     _("&Memory Level"),
     GetImage_memory(),
     _("Memory Level"),
     wxITEM_NORMAL);
   m_SetterPosition = new wxSpinCtrl(
-    tb,
+    m_ToolBar,
     ID_METER_FRAME_SPIN,
     wxEmptyString,
     wxDefaultPosition,
@@ -271,13 +280,13 @@ GOFrame::GOFrame(
     wxSP_ARROW_KEYS,
     0,
     999);
-  tb->AddControl(m_SetterPosition);
+  m_ToolBar->AddControl(m_SetterPosition);
   m_SetterPosition->SetValue(0);
 
-  tb->AddTool(
+  m_ToolBar->AddTool(
     ID_VOLUME, _("&Volume"), GetImage_volume(), _("Volume"), wxITEM_NORMAL);
   m_Volume = new wxSpinCtrl(
-    tb,
+    m_ToolBar,
     ID_METER_AUDIO_SPIN,
     wxEmptyString,
     wxDefaultPosition,
@@ -285,14 +294,13 @@ GOFrame::GOFrame(
     wxSP_ARROW_KEYS,
     -120,
     20);
-  tb->AddControl(m_Volume);
-
-  m_VolumeControl = new wxControl(tb, wxID_ANY);
+  m_ToolBar->AddControl(m_Volume);
+  m_VolumeControl = new wxControl(m_ToolBar, wxID_ANY);
+  m_VolumeControlTool = m_ToolBar->AddControl(m_VolumeControl);
   AdjustVolumeControlWithSettings();
-  tb->AddControl(m_VolumeControl);
   m_Volume->SetValue(m_config.Volume());
 
-  tb->AddTool(
+  m_ToolBar->AddTool(
     ID_RELEASELENGTH,
     _("&Release tail length"),
     GetImage_reverb(),
@@ -303,20 +311,23 @@ GOFrame::GOFrame(
   for (unsigned i = 1; i <= 60; i++)
     choices.push_back(wxString::Format(_("%d ms"), i * 50));
   m_ReleaseLength = new wxChoice(
-    tb, ID_RELEASELENGTH_SELECT, wxDefaultPosition, wxDefaultSize, choices);
-  tb->AddControl(m_ReleaseLength);
-  unsigned n = m_config.ReleaseLength();
-  m_ReleaseLength->SetSelection(n / 50);
-  m_Sound.GetEngine().SetReleaseLength(n);
+    m_ToolBar,
+    ID_RELEASELENGTH_SELECT,
+    wxDefaultPosition,
+    wxDefaultSize,
+    choices);
+  m_ToolBar->AddControl(m_ReleaseLength);
+  m_Sound.GetEngine().SetReleaseLength(m_config.ReleaseLength());
+  UpdateReleaseLength();
 
-  tb->AddTool(
+  m_ToolBar->AddTool(
     ID_TRANSPOSE,
     _("&Transpose"),
     GetImage_transpose(),
     _("Transpose"),
     wxITEM_NORMAL);
   m_Transpose = new wxSpinCtrl(
-    tb,
+    m_ToolBar,
     ID_METER_TRANSPOSE_SPIN,
     wxEmptyString,
     wxDefaultPosition,
@@ -324,17 +335,17 @@ GOFrame::GOFrame(
     wxSP_ARROW_KEYS,
     -11,
     11);
-  tb->AddControl(m_Transpose);
+  m_ToolBar->AddControl(m_Transpose);
   m_Transpose->SetValue(m_config.Transpose());
 
-  tb->AddTool(
+  m_ToolBar->AddTool(
     ID_POLYPHONY,
     _("&Polyphony"),
     GetImage_polyphony(),
     _("Polyphony"),
     wxITEM_NORMAL);
   m_Polyphony = new wxSpinCtrl(
-    tb,
+    m_ToolBar,
     ID_METER_POLY_SPIN,
     wxEmptyString,
     wxDefaultPosition,
@@ -342,27 +353,19 @@ GOFrame::GOFrame(
     wxSP_ARROW_KEYS,
     1,
     MAX_POLYPHONY);
-  tb->AddControl(m_Polyphony);
+  m_ToolBar->AddControl(m_Polyphony);
 
-  m_SamplerUsage = new GOAudioGauge(tb, wxID_ANY, wxDefaultPosition);
-  tb->AddControl(m_SamplerUsage);
+  m_SamplerUsage = new GOAudioGauge(m_ToolBar, wxID_ANY, wxDefaultPosition);
+  m_ToolBar->AddControl(m_SamplerUsage);
   m_Polyphony->SetValue(m_config.PolyphonyLimit());
 
-  tb->AddTool(
+  m_ToolBar->AddTool(
     ID_AUDIO_PANIC,
     _("&Panic\tEscape"),
     GetImage_panic(),
     _("Panic"),
     wxITEM_NORMAL);
 
-  m_panel_menu = new wxMenu();
-
-  wxMenuBar *menu_bar = new wxMenuBar;
-  menu_bar->Append(m_file_menu, _("&File"));
-  menu_bar->Append(m_audio_menu, _("&Audio/Midi"));
-  menu_bar->Append(m_panel_menu, _("&Panel"));
-  menu_bar->Append(help_menu, _("&Help"));
-  SetMenuBar(menu_bar);
   SetAutoLayout(true);
 
   UpdateSize();
@@ -387,6 +390,17 @@ bool GOFrame::AdjustVolumeControlWithSettings() {
   bool rc = false;
 
   if (count != m_VolumeGauge.size()) {
+    const wxPortId portId = wxPlatformInfo::Get().GetPortId();
+    const bool isOsX = portId == wxPORT_COCOA || portId == wxPORT_OSX;
+    int volCtlId = m_VolumeControlTool->GetId();
+    int volCtlPos = m_ToolBar->GetToolPos(volCtlId);
+
+    // OsX doesn't relayout the toolbar correctly after changing the size of
+    // a control so we need to remove it and to reinsert it later
+    // But RemoveTool hangs on windows, so we do it only on OsX
+    if (isOsX)
+      m_ToolBar->RemoveTool(volCtlId);
+
     m_VolumeGauge.clear();
     m_VolumeControl->DestroyChildren();
     wxBoxSizer *sizer = new wxBoxSizer(wxHORIZONTAL);
@@ -405,6 +419,11 @@ bool GOFrame::AdjustVolumeControlWithSettings() {
 
     m_VolumeControl->SetSizer(sizer);
     sizer->Fit(m_VolumeControl);
+
+    // reinsert the control and relayout the toolbar on OsX
+    if (isOsX)
+      m_ToolBar->InsertTool(volCtlPos, m_VolumeControlTool);
+    m_ToolBar->Realize();
     rc = true;
   }
   return rc;
@@ -455,6 +474,12 @@ void GOFrame::SetPosSize(const GOLogicalRect &lRect) {
   }
 }
 
+void GOFrame::UpdateReleaseLength() {
+  unsigned n = m_config.ReleaseLength();
+
+  m_ReleaseLength->SetSelection(n / 50);
+}
+
 void GOFrame::UpdateVolumeControlWithSettings() {
   m_isMeterReady = false;
   if (AdjustVolumeControlWithSettings())
@@ -491,7 +516,7 @@ void GOFrame::Init(wxString filename) {
     event.SetClientData(pReasons);
     GetEventHandler()->AddPendingEvent(event);
   }
-  GOArchiveManager manager(m_config, m_config.OrganCachePath);
+  GOArchiveManager manager(m_config, m_config.OrganCachePath());
   manager.RegisterPackageDirectory(m_config.GetPackageDirectory());
   manager.RegisterPackageDirectory(m_config.OrganPackagePath());
   if (!filename.IsEmpty())
@@ -561,6 +586,7 @@ void GOFrame::Open(const GOOrgan &organ) {
   GOProgressDialog dlg;
   m_doc = new GODocument(this, &m_Sound);
   m_doc->Load(&dlg, organ);
+  UpdateReleaseLength();
   UpdatePanelMenu();
 }
 
@@ -575,9 +601,9 @@ void GOFrame::OnPanel(wxCommandEvent &event) {
 
 void GOFrame::UpdatePanelMenu() {
   GODocument *doc = GetDocument();
-  GODefinitionFile *organfile = doc ? doc->GetOrganFile() : NULL;
-  unsigned panelcount = (organfile && organfile->GetPanelCount())
-    ? organfile->GetPanelCount()
+  GOOrganController *organController = doc ? doc->GetOrganFile() : NULL;
+  unsigned panelcount = (organController && organController->GetPanelCount())
+    ? organController->GetPanelCount()
     : 0;
   panelcount = std::min(panelcount, (unsigned)(ID_PANEL_LAST - ID_PANEL_FIRST));
 
@@ -586,7 +612,7 @@ void GOFrame::UpdatePanelMenu() {
       m_panel_menu->FindItemByPosition(m_panel_menu->GetMenuItemCount() - 1));
 
   for (unsigned i = 0; i < panelcount; i++) {
-    GOGUIPanel *panel = organfile->GetPanel(i);
+    GOGUIPanel *panel = organController->GetPanel(i);
     wxMenu *menu = NULL;
     if (panel->GetGroupName() == wxEmptyString)
       menu = m_panel_menu;
@@ -641,10 +667,10 @@ void GOFrame::UpdateRecentMenu() {
 
 void GOFrame::UpdateTemperamentMenu() {
   GODocument *doc = GetDocument();
-  GODefinitionFile *organfile = doc ? doc->GetOrganFile() : NULL;
+  GOOrganController *organController = doc ? doc->GetOrganFile() : NULL;
   wxString temperament = wxEmptyString;
-  if (organfile)
-    temperament = organfile->GetTemperament();
+  if (organController)
+    temperament = organController->GetTemperament();
 
   while (m_temperament_menu->GetMenuItemCount() > 0)
     m_temperament_menu->Destroy(m_temperament_menu->FindItemByPosition(
@@ -655,7 +681,7 @@ void GOFrame::UpdateTemperamentMenu() {
        i++) {
     const GOTemperament &t = m_config.GetTemperaments().GetTemperament(i);
     wxMenu *menu;
-    wxString group = t.GetGroup();
+    wxString group = t.GetGroupTitle();
     if (group == wxEmptyString)
       menu = m_temperament_menu;
     else {
@@ -672,7 +698,7 @@ void GOFrame::UpdateTemperamentMenu() {
     }
     wxMenuItem *e = menu->Append(
       ID_TEMPERAMENT_0 + i, t.GetTitle(), wxEmptyString, wxITEM_CHECK);
-    e->Enable(organfile);
+    e->Enable(organController);
     e->Check(t.GetName() == temperament);
   }
 }
@@ -710,7 +736,7 @@ void GOFrame::OnMeters(wxCommandEvent &event) {
 
 void GOFrame::OnUpdateLoaded(wxUpdateUIEvent &event) {
   GODocument *doc = GetDocument();
-  GODefinitionFile *organfile = doc ? doc->GetOrganFile() : NULL;
+  GOOrganController *organController = doc ? doc->GetOrganFile() : NULL;
 
   if (ID_PRESET_0 <= event.GetId() && event.GetId() <= ID_PRESET_LAST) {
     event.Check(m_config.Preset() == (unsigned)(event.GetId() - ID_PRESET_0));
@@ -719,8 +745,8 @@ void GOFrame::OnUpdateLoaded(wxUpdateUIEvent &event) {
 
   if (event.GetId() == ID_AUDIO_MEMSET)
     event.Check(
-      organfile && organfile->GetSetter()
-      && organfile->GetSetter()->IsSetterActive());
+      organController && organController->GetSetter()
+      && organController->GetSetter()->IsSetterActive());
   else if (event.GetId() == ID_ORGAN_EDIT)
     event.Check(doc && doc->WindowExists(GODocument::ORGAN_DIALOG, NULL));
   else if (event.GetId() == ID_MIDI_LIST)
@@ -729,15 +755,15 @@ void GOFrame::OnUpdateLoaded(wxUpdateUIEvent &event) {
     event.Check(m_MidiMonitor);
 
   if (event.GetId() == ID_FILE_CACHE_DELETE)
-    event.Enable(organfile && organfile->CachePresent());
+    event.Enable(organController && organController->CachePresent());
   else if (event.GetId() == ID_FILE_CACHE)
-    event.Enable(organfile && organfile->IsCacheable());
+    event.Enable(organController && organController->IsCacheable());
   else if (event.GetId() == ID_MIDI_MONITOR)
     event.Enable(true);
   else
     event.Enable(
-      organfile
-      && (event.GetId() == ID_FILE_REVERT ? organfile->IsCustomized() : true));
+      organController
+      && (event.GetId() == ID_FILE_REVERT ? organController->IsCustomized() : true));
 }
 
 void GOFrame::OnPreset(wxCommandEvent &event) {
@@ -794,7 +820,7 @@ void GOFrame::OnOpen(wxCommandEvent &event) {
     _("Open organ"),
     m_config.OrganPath(),
     wxEmptyString,
-    _("Sample set definition files (*.organ)|*.organ"),
+    GOStdFileName::getOdfDlgWildcard(),
     wxFD_OPEN | wxFD_FILE_MUST_EXIST);
   if (dlg.ShowModal() == wxID_OK) {
     Open(GOOrgan(dlg.GetPath()));
@@ -807,7 +833,7 @@ void GOFrame::OnInstall(wxCommandEvent &event) {
     _("Install organ package"),
     m_config.OrganPath(),
     wxEmptyString,
-    _("Organ package (*.orgue)|*.orgue"),
+    GOStdFileName::getPackageDlgWildcard(),
     wxFD_OPEN | wxFD_FILE_MUST_EXIST);
   if (dlg.ShowModal() == wxID_OK)
     if (InstallOrganPackage(dlg.GetPath())) {
@@ -1037,7 +1063,7 @@ void GOFrame::OnSettings(wxCommandEvent &event) {
   GOSettingsDialog dialog(this, m_Sound, pReasons);
 
   if (dialog.ShowModal() == wxID_OK) {
-    GOArchiveManager manager(m_config, m_config.OrganCachePath);
+    GOArchiveManager manager(m_config, m_config.OrganCachePath());
     manager.RegisterPackageDirectory(m_config.OrganPackagePath());
 
     UpdateVolumeControlWithSettings();
@@ -1157,6 +1183,8 @@ void GOFrame::OnSettingsTranspose(wxCommandEvent &event) {
 void GOFrame::OnSettingsReleaseLength(wxCommandEvent &event) {
   m_config.ReleaseLength(m_ReleaseLength->GetSelection() * 50);
   m_Sound.GetEngine().SetReleaseLength(m_config.ReleaseLength());
+  if (m_doc && m_doc->GetOrganFile())
+    m_doc->GetOrganFile()->SetReleaseTail(m_config.ReleaseLength());
 }
 
 void GOFrame::OnHelpAbout(wxCommandEvent &event) { DoSplash(false); }
@@ -1247,7 +1275,7 @@ void GOFrame::OnRenameFile(wxRenameFileEvent &event) {
 }
 
 bool GOFrame::InstallOrganPackage(wxString name) {
-  GOArchiveManager manager(m_config, m_config.OrganCachePath);
+  GOArchiveManager manager(m_config, m_config.OrganCachePath());
   wxString result = manager.InstallPackage(name);
   if (result != wxEmptyString) {
     GOMessageBox(result, _("Error"), wxOK | wxICON_ERROR, this);
