@@ -237,7 +237,8 @@ GOConfig::GOConfig(wxString instance)
     GOStdPath::GetGrandOrgueSubDir(_("MIDI recordings")));
 }
 
-GOConfig::~GOConfig() { Flush(); }
+GOConfig::~GOConfig() { /* Flush(); */
+}
 
 void load_ports_config(
   GOConfigReader &cfg,
@@ -492,10 +493,6 @@ GOMidiReceiverBase *GOConfig::FindMidiEvent(
   return NULL;
 }
 
-const wxString GOConfig::GetResourceDirectory() {
-  return m_ResourceDir.c_str();
-}
-
 const wxString GOConfig::GetPackageDirectory() {
   return m_ResourceDir + wxFileName::GetPathSeparator() + wxT("packages");
 }
