@@ -7,6 +7,8 @@
 
 #include "GOOrganDialog.h"
 
+#include <unordered_set>
+
 #include <wx/button.h>
 #include <wx/checkbox.h>
 #include <wx/choicdlg.h>
@@ -20,12 +22,13 @@
 #include <wx/stattext.h>
 #include <wx/treectrl.h>
 
-#include "GODefinitionFile.h"
-#include "GOEvent.h"
-#include "GORank.h"
-#include "GOSampleStatistic.h"
-#include "GOWindchest.h"
 #include "config/GOConfig.h"
+#include "model/GORank.h"
+#include "model/GOWindchest.h"
+
+#include "GOEvent.h"
+#include "GOOrganController.h"
+#include "GOSampleStatistic.h"
 
 class OrganTreeItemData : public wxTreeItemData {
 public:
@@ -44,6 +47,7 @@ BEGIN_EVENT_TABLE(GOOrganDialog, wxDialog)
 EVT_BUTTON(ID_EVENT_APPLY, GOOrganDialog::OnEventApply)
 EVT_BUTTON(ID_EVENT_RESET, GOOrganDialog::OnEventReset)
 EVT_BUTTON(ID_EVENT_DEFAULT, GOOrganDialog::OnEventDefault)
+EVT_BUTTON(ID_EVENT_DEFAULT_ALL, GOOrganDialog::OnEventDefaultAll)
 EVT_BUTTON(wxID_OK, GOOrganDialog::OnOK)
 EVT_BUTTON(wxID_CANCEL, GOOrganDialog::OnCancel)
 EVT_TREE_SEL_CHANGING(ID_EVENT_TREE, GOOrganDialog::OnTreeChanging)
@@ -69,7 +73,7 @@ EVT_BUTTON(ID_EVENT_COLLAPSE, GOOrganDialog::OnCollapse)
 END_EVENT_TABLE()
 
 GOOrganDialog::GOOrganDialog(
-  GODocumentBase *doc, wxWindow *parent, GODefinitionFile *organfile)
+  GODocumentBase *doc, wxWindow *parent, GOOrganController *organController)
   : wxDialog(
     parent,
     wxID_ANY,
@@ -78,7 +82,7 @@ GOOrganDialog::GOOrganDialog(
     wxDefaultSize,
     wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER),
     GOView(doc, this),
-    m_organfile(organfile),
+    m_OrganController(organController),
     m_Apply(NULL),
     m_Reset(NULL),
     m_Last(NULL),
@@ -185,7 +189,7 @@ GOOrganDialog::GOOrganDialog(
   grid->Add(m_AudioGroup);
   m_AudioGroup->Append(wxEmptyString);
   std::vector<wxString> audio_groups
-    = m_organfile->GetSettings().GetAudioGroups();
+    = m_OrganController->GetSettings().GetAudioGroups();
   for (unsigned i = 0; i < audio_groups.size(); i++)
     m_AudioGroup->Append(audio_groups[i]);
 
@@ -298,12 +302,15 @@ GOOrganDialog::GOOrganDialog(
   m_Apply = new wxButton(scroll, ID_EVENT_APPLY, _("Apply"));
   m_Reset = new wxButton(scroll, ID_EVENT_RESET, _("Reset"));
   m_Default = new wxButton(scroll, ID_EVENT_DEFAULT, _("Default"));
+  m_DefaultAll
+    = new wxButton(scroll, ID_EVENT_DEFAULT_ALL, _("Default for All"));
   buttons->Add(m_Default);
+  buttons->Add(m_DefaultAll);
   buttons->Add(m_Reset);
   buttons->Add(m_Apply);
   settingSizer->Add(buttons);
 
-  box1 = new wxStaticBoxSizer(wxVERTICAL, scroll, _("Sample informations"));
+  box1 = new wxStaticBoxSizer(wxVERTICAL, scroll, _("Sample information"));
   grid = new wxFlexGridSizer(2, 5, 5);
   box1->Add(grid, 0, wxEXPAND | wxALL, 5);
   settingSizer->Add(box1, 0, wxEXPAND | wxALL, 5);
@@ -334,7 +341,7 @@ GOOrganDialog::GOOrganDialog(
     0,
     wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL | wxBOTTOM,
     5);
-  if (m_organfile->GetIgnorePitch())
+  if (m_OrganController->GetIgnorePitch())
     m_IgnorePitch->SetValue(true);
 
   settingSizer->Add(box3, 0, wxEXPAND | wxALL, 4);
@@ -718,7 +725,7 @@ void GOOrganDialog::FillTree(wxTreeItemId parent, GOPipeConfigNode &config) {
 
 void GOOrganDialog::FillTree() {
   wxTreeItemId id_root;
-  FillTree(id_root, m_organfile->GetPipeConfig());
+  FillTree(id_root, m_OrganController->GetPipeConfig());
 }
 
 void GOOrganDialog::OnEventApply(wxCommandEvent &e) {
@@ -826,14 +833,41 @@ void GOOrganDialog::OnEventReset(wxCommandEvent &e) {
   Load();
 }
 
-void GOOrganDialog::OnEventDefault(wxCommandEvent &e) {
+void GOOrganDialog::ResetSelectedToDefault(bool isForChildren) {
   wxArrayTreeItemIds entries;
   m_Tree->GetSelections(entries);
 
-  for (unsigned i = 0; i < entries.size(); i++) {
-    OrganTreeItemData *e = (OrganTreeItemData *)m_Tree->GetItemData(entries[i]);
-    if (!e)
-      continue;
+  std::unordered_set<OrganTreeItemData *> oiSet;
+
+  // Fill idSet with entries
+  for (const wxTreeItemId id : entries) {
+    OrganTreeItemData *p = (OrganTreeItemData *)m_Tree->GetItemData(id);
+
+    if (p)
+      oiSet.insert(p);
+  }
+
+  // add the children
+  if (isForChildren) {
+    // entries.size() it may not be precalculated because it is increased
+    for (unsigned i = 0; i < entries.size(); i++) {
+      const wxTreeItemId id = entries[i];
+      wxTreeItemIdValue cookie;
+
+      for (wxTreeItemId c = m_Tree->GetFirstChild(id, cookie); c.IsOk();
+           c = m_Tree->GetNextChild(id, cookie)) {
+        OrganTreeItemData *p = (OrganTreeItemData *)m_Tree->GetItemData(c);
+
+        if (p && oiSet.find(p) == oiSet.end()) {
+          oiSet.insert(p);
+          entries.push_back(c);
+          // c's children will be scanned later in the loop
+        }
+      }
+    }
+  }
+
+  for (OrganTreeItemData *e : oiSet) {
     e->config->SetAmplitude(e->config->GetDefaultAmplitude());
     e->config->SetGain(e->config->GetDefaultGain());
     e->config->SetTuning(e->config->GetDefaultTuning());
@@ -851,6 +885,14 @@ void GOOrganDialog::OnEventDefault(wxCommandEvent &e) {
   Load();
 }
 
+void GOOrganDialog::OnEventDefault(wxCommandEvent &e) {
+  ResetSelectedToDefault(false);
+}
+
+void GOOrganDialog::OnEventDefaultAll(wxCommandEvent &e) {
+  ResetSelectedToDefault(true);
+}
+
 void GOOrganDialog::OnTreeChanging(wxTreeEvent &e) {
   if (Changed()) {
     GOMessageBox(
@@ -903,9 +945,9 @@ void GOOrganDialog::OnOK(wxCommandEvent &event) {
       _("Please apply changes first"), _("Error"), wxOK | wxICON_ERROR, this);
     return;
   }
-  m_organfile->SetIgnorePitch(m_IgnorePitch->GetValue());
-  m_organfile->SetTemperament(m_organfile->GetTemperament());
-  m_organfile->Modified();
+  m_OrganController->SetIgnorePitch(m_IgnorePitch->GetValue());
+  m_OrganController->SetTemperament(m_OrganController->GetTemperament());
+  m_OrganController->SetOrganModified();
   Destroy();
 }
 
@@ -937,7 +979,7 @@ void GOOrganDialog::OnAudioGroupAssitant(wxCommandEvent &e) {
   }
   wxArrayString strs;
   std::vector<wxString> group_list
-    = m_organfile->GetSettings().GetAudioGroups();
+    = m_OrganController->GetSettings().GetAudioGroups();
   for (unsigned i = 0; i < group_list.size(); i++)
     strs.Add(group_list[i]);
 
